Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Elastic Kubernetes Service.

Actions, resources, and condition keys for Amazon Elastic Kubernetes Service - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Elastic Kubernetes Service

Amazon Elastic Kubernetes Service (service prefix: `eks` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Elastic Kubernetes Service
- Resource types defined by Amazon Elastic Kubernetes Service
- Condition keys for Amazon Elastic Kubernetes Service

## Actions defined by Amazon Elastic Kubernetes Service

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AccessKubernetesApi [permission only] | Grants permission to view Kubernetes objects via AWS EKS console | Read | cluster* |  |
AssociateEncryptionConfig | Grants permission to associate encryption configuration to a cluster | Write | cluster* |  |
AssociateIdentityProviderConfig | Grants permission to associate an identity provider configuration to a cluster | Write | cluster* |  |
| aws:RequestTag/${TagKey} aws:TagKeys eks:clientId eks:issuerUrl |
CreateAddon | Grants permission to create an Amazon EKS add-on | Write | cluster* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateCluster | Grants permission to create an Amazon EKS cluster | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateFargateProfile | Grants permission to create an AWS Fargate profile | Write | cluster* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateNodegroup | Grants permission to create an Amazon EKS Nodegroup | Write | cluster* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteAddon | Grants permission to delete an Amazon EKS add-on | Write | addon* |  |
DeleteCluster | Grants permission to delete an Amazon EKS cluster | Write | cluster* |  |
DeleteFargateProfile | Grants permission to delete an AWS Fargate profile | Write | fargateprofile* |  |
DeleteNodegroup | Grants permission to delete an Amazon EKS Nodegroup | Write | nodegroup* |  |
DeregisterCluster | Grants permission to deregister an External cluster | Write | cluster* |  |
DescribeAddon | Grants permission to retrieve descriptive information about an Amazon EKS add-on | Read | addon* |  |
DescribeAddonConfiguration | Grants permission to list configuration options about an Amazon EKS add-on | Read |  |  |
DescribeAddonVersions | Grants permission to retrieve descriptive version information about the add-ons that Amazon EKS Add-ons supports | Read |  |  |
DescribeCluster | Grants permission to retrieve descriptive information about an Amazon EKS cluster | Read | cluster* |  |
DescribeFargateProfile | Grants permission to retrieve descriptive information about an AWS Fargate profile associated with a cluster | Read | fargateprofile* |  |
DescribeIdentityProviderConfig | Grants permission to retrieve descriptive information about an Idp config associated with a cluster | Read | identityproviderconfig* |  |
DescribeNodegroup | Grants permission to retrieve descriptive information about an Amazon EKS nodegroup | Read | nodegroup* |  |
DescribeUpdate | Grants permission to retrieve a given update for a given Amazon EKS cluster/nodegroup/add-on (in the specified or default region) | Read | cluster* |  |
addon |  |
nodegroup |  |
DisassociateIdentityProviderConfig | Grants permission to delete an asssociated Idp config | Write | identityproviderconfig* |  |
ListAddons | Grants permission to list the Amazon EKS add-ons in your AWS account (in the specified or default region) for a given cluster | List | cluster* |  |
ListClusters | Grants permission to list the Amazon EKS clusters in your AWS account (in the specified or default region) | List |  |  |
ListFargateProfiles | Grants permission to list the AWS Fargate profiles in your AWS account (in the specified or default region) associated with a given cluster | List | cluster* |  |
ListIdentityProviderConfigs | Grants permission to list the Idp configs in your AWS account (in the specified or default region) associated with a given cluster | List | cluster* |  |
ListNodegroups | Grants permission to list the Amazon EKS nodegroups in your AWS account (in the specified or default region) attached to given cluster | List | cluster* |  |
ListTagsForResource | Grants permission to list tags for the specified resource | Read | addon |  |
cluster |  |
fargateprofile |  |
identityproviderconfig |  |
nodegroup |  |
ListUpdates | Grants permission to list the updates for a given Amazon EKS cluster/nodegroup/add-on (in the specified or default region) | List | cluster* |  |
addon |  |
nodegroup |  |
RegisterCluster | Grants permission to register an External cluster | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
TagResource | Grants permission to tag the specified resource | Tagging | addon |  |
cluster |  |
fargateprofile |  |
identityproviderconfig |  |
nodegroup |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to untag the specified resource | Tagging | addon |  |
cluster |  |
fargateprofile |  |
identityproviderconfig |  |
nodegroup |  |
| aws:TagKeys |
UpdateAddon | Grants permission to update Amazon EKS add-on configurations, such as the VPC-CNI version | Write | addon* |  |
UpdateClusterConfig | Grants permission to update Amazon EKS cluster configurations (eg: API server endpoint access) | Write | cluster* |  |
UpdateClusterVersion | Grants permission to update the Kubernetes version of an Amazon EKS cluster | Write | cluster* |  |
UpdateNodegroupConfig | Grants permission to update Amazon EKS nodegroup configurations (eg: min/max/desired capacity or labels) | Write | nodegroup* |  |
UpdateNodegroupVersion | Grants permission to update the Kubernetes version of an Amazon EKS nodegroup | Write | nodegroup* |  |

## Resource types defined by Amazon Elastic Kubernetes Service

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
cluster | `arn:$ { Partition}:eks:$ { Region}:$ { Account}:cluster/$ { ClusterName}` | aws:ResourceTag/${TagKey}
nodegroup | `arn:$ { Partition}:eks:$ { Region}:$ { Account}:nodegroup/$ { ClusterName}/$ { NodegroupName}/$ { UUID}` | aws:ResourceTag/${TagKey}
addon | `arn:$ { Partition}:eks:$ { Region}:$ { Account}:addon/$ { ClusterName}/$ { AddonName}/$ { UUID}` | aws:ResourceTag/${TagKey}
fargateprofile | `arn:$ { Partition}:eks:$ { Region}:$ { Account}:fargateprofile/$ { ClusterName}/$ { FargateProfileName}/$ { UUID}` | aws:ResourceTag/${TagKey}
identityproviderconfig | `arn:$ { Partition}:eks:$ { Region}:$ { Account}:identityproviderconfig/$ { ClusterName}/$ { IdentityProviderType}/$ { IdentityProviderConfigName}/$ { UUID}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Elastic Kubernetes Service

Amazon Elastic Kubernetes Service defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by a key that is present in the request the user makes to the EKS service | String
aws:ResourceTag/${TagKey} | Filters access by a tag key and value pair | String
aws:TagKeys | Filters access by the list of all the tag key names present in the request the user makes to the EKS service | ArrayOfString
eks:clientId | Filters access by the clientId present in the associateIdentityProviderConfig request the user makes to the EKS service | String
eks:issuerUrl | Filters access by the issuerUrl present in the associateIdentityProviderConfig request the user makes to the EKS service | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.